@@ -35,6 +35,11 @@ class ConfigDialog;
 class QGraphicsSceneDragDropEvent;
 class SlideShow;
 
+namespace Plasma
+{
+    class ToolButton;
+    class Frame;
+}
 
 class Frame : public Plasma::Applet
 {
@@ -47,7 +52,6 @@ public:
                         const QRect &contentsRect);
     void init();
     QSizeF contentSizeHint() const;
-    virtual QList<QAction*> contextualActions();
 
 public slots:
     void createConfigurationInterface(KConfigDialog *parent);
@@ -57,20 +61,26 @@ protected Q_SLOTS:
     void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
     void configAccepted();
     void updatePicture();
+    void nextPicture();
+    void previousPicture();
     void slotOpenPicture();
 
 private Q_SLOTS:
     void addDir();
     void removeDir();
     void updateButtons();
+    void delayedUpdateSize();
 
 protected:
     void constraintsEvent(Plasma::Constraints constraints);
-    void updateMenu();
+    void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
+    void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
+    QSizeF sizeHint(Qt::SizeHint which, const QSizeF &constraint) const;
 
 private:
     void stopPotd();
     void initSlideShow();
+    void checkSlideFrame();
 
     /// The current color of the frame
     QColor m_frameColor;
@@ -95,9 +105,6 @@ private:
     int m_slideshowTime;
     /// The size of the current picture
     QSize m_pictureSize;
-    /// The action list for the context menu
-    QList<QAction*> m_actions;
-    QAction* m_openPicture;
     /// Frame & shadow outline thickness
     int m_frameOutline;
     int m_swOutline;
@@ -107,6 +114,11 @@ private:
     bool m_random;
     bool m_recursiveSlideShow;
     SlideShow* m_mySlideShow;
+    QPixmap m_pixmap;
+    QTimer* m_updateTimer;
+    Plasma::ToolButton* m_backButton;
+    Plasma::ToolButton* m_nextButton;
+    Plasma::Frame* m_slideFrame;
 };
 
 K_EXPORT_PLASMA_APPLET(frame, Frame)
