@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2007 Ivan Cukic <ivan.cukic(at)kde.org>
  *   Copyright (C) 2007 Robert Knight <robertknight@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -20,15 +20,19 @@
 
 #include "Devices.h"
 
-#include <QMessageBox>
+#include <KMessageBox>
 #include <KRun>
 #include <KLocalizedString>
+#include <KStandardDirs>
 
 #include <QDBusInterface>
 #include <QDBusReply>
-#include <KDebug>
+#include <QFile>
+#include <QDebug>
 #include <KIcon>
 
+#include "logger/Logger.h"
+
 #include <solid/device.h>
 #include <solid/deviceinterface.h>
 #include <solid/devicenotifier.h>
@@ -39,11 +43,22 @@
 
 namespace Models {
 
-#define StringCoalesce(A, B) (A == "")?(B):(A)
-
 Devices::Devices(Type filter)
     : m_filter(filter)
 {
+    switch (filter) {
+        case Models::Devices::Removable:
+            setSelfTitle(i18n("Removable"));
+            setSelfIcon(KIcon("media-optical"));
+            break;
+        case Models::Devices::Fixed:
+            setSelfTitle(i18n("Fixed"));
+            setSelfIcon(KIcon("drive-harddisk"));
+            break;
+        default:
+            setSelfIcon(KIcon("drive-harddisk"));
+    }
+
     load();
 
     connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)),
@@ -58,20 +73,13 @@ Devices::~Devices()
 
 void Devices::deviceRemoved(const QString & udi)
 {
-    QMutableListIterator<Item> i(m_items);
-    int index = 0;
-
-    while (i.hasNext()) {
-        Item & item = i.next();
-        if (item.data.toString() == udi) {
-            i.remove();
-            // TODO: m_udis.removeAll(udi);
-            emit itemDeleted(index);
+    for (int i = size() - 1; i >= 0; i--) {
+        const Item * item = & itemAt(i);
+        if (item->data.toString() == udi) {
+            removeAt(i);
             return;
         }
-        ++index;
     }
-
 }
 
 void Devices::deviceAdded(const QString & udi)
@@ -81,7 +89,7 @@ void Devices::deviceAdded(const QString & udi)
 
 void Devices::addDevice(const Solid::Device & device)
 {
-    const Solid::StorageAccess * access = device.as<Solid::StorageAccess>();
+    const Solid::StorageAccess * access = device.as < Solid::StorageAccess > ();
 
     if (!access) return;
 
@@ -105,11 +113,15 @@ void Devices::addDevice(const Solid::Device & device)
         access, SIGNAL(accessibilityChanged(bool, const QString &)),
         this, SLOT(udiAccessibilityChanged(bool, const QString &))
     );
-    //m_udis[access] = device.udi();
+
+    QString description = access->filePath();
+    if (!access->isAccessible() || description.isEmpty()) {
+        description = i18n("Unmounted");
+    }
 
     add(
         device.product(),
-        StringCoalesce(access->filePath(), i18n("Unmounted")),
+        description,
         KIcon(device.icon()),
         device.udi()
     );
@@ -120,40 +132,98 @@ void Devices::udiAccessibilityChanged(bool accessible, const QString & udi)
     Q_UNUSED(accessible);
 
     Solid::StorageAccess * access = Solid::Device(udi).as<Solid::StorageAccess>();
-    //if (!m_udis.contains(access)) {
-    //    return;
-    //}
 
-    QMutableListIterator<Item> i(m_items);
-    int index = 0;
+    for (int i = size() - 1; i >= 0; i--) {
+        Item * item = const_cast < Item * > (& itemAt(i));
+        if (item->data.toString() == udi) {
+            item->description = access->filePath();
+            if (!access->isAccessible() || item->description.isEmpty()) {
+                item->description = i18n("Unmounted");
+            }
 
-    while (i.hasNext()) {
-        Item & item = i.next();
-        if (item.data.toString() == udi) {
-            break;
+            emit itemAltered(i);
+            return;
         }
-        ++index;
     }
-
-    m_items[index].description = StringCoalesce(access->filePath(), i18n("Unmounted"));
-    emit itemAltered(index);
-
 }
 
-
 void Devices::load()
 {
     QList<Solid::Device> deviceList =
         Solid::Device::listFromType(Solid::DeviceInterface::StorageAccess, QString());
 
+    // Loading hidden UDIs list
+    QFile file(
+        KStandardDirs::locateLocal("data",
+        "kfileplaces/bookmarks.xml"));
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        return;
+    }
+    m_xmlReader.setDevice(& file);
+
+    while (!m_xmlReader.atEnd()) {
+        m_xmlReader.readNext();
+
+        if (m_xmlReader.isStartElement()) {
+            if (m_xmlReader.name() == "xbel") {
+                readXbel();
+            }
+        }
+    }
+
+    // Loading items
     setEmitInhibited(true);
     foreach(const Solid::Device & device, deviceList) {
-        addDevice(device);
+        if (!m_udis.contains(device.udi())) {
+            addDevice(device);
+        }
     }
     setEmitInhibited(false);
     emit updated();
 }
 
+void Devices::readXbel()
+{
+    while (!m_xmlReader.atEnd()) {
+        m_xmlReader.readNext();
+
+        if (m_xmlReader.isEndElement() &&
+                m_xmlReader.name() == "xbel")
+            break;
+
+        if (m_xmlReader.isStartElement()) {
+            if (m_xmlReader.name() == "separator")
+                readItem();
+        }
+    }
+}
+
+void Devices::readItem()
+{
+    QString udi;
+    bool showItem = true;
+
+    while (!m_xmlReader.atEnd()) {
+        m_xmlReader.readNext();
+
+        if (m_xmlReader.isEndElement() && m_xmlReader.name() == "separator") {
+            break;
+        }
+
+        if (m_xmlReader.name() == "UDI") {
+            udi = m_xmlReader.readElementText();
+        } else if (m_xmlReader.name() == "IsHidden") {
+            if (m_xmlReader.readElementText() == "true") {
+                showItem = false;
+            }
+        }
+    }
+
+    if (!showItem) {
+        m_udis << udi;
+    }
+}
+
 void Devices::freeSpaceInfoAvailable(const QString & mountPoint, quint64 kbSize, quint64 kbUsed, quint64 kbAvailable)
 {
     Q_UNUSED(mountPoint);
@@ -164,25 +234,12 @@ void Devices::freeSpaceInfoAvailable(const QString & mountPoint, quint64 kbSize,
 
 void Devices::activate(int index)
 {
-    if (index > m_items.size() - 1) return;
+    if (index > size() - 1) return;
 
-    QString udi = m_items.at(index).data.toString();
-    Solid::StorageAccess * access = Solid::Device(udi).as<Solid::StorageAccess>();
+    QString udi = itemAt(index).data.toString();
+    Logger::self()->log("devices-model", udi);
 
-    if (!access) return;
-
-    if (!access->isAccessible()) {
-        //m_devicesMounting << udi;
-        connect(access, SIGNAL(setupDone(Solid::ErrorType, QVariant, const QString &)),
-            this, SLOT(deviceSetupDone(Solid::ErrorType, QVariant, const QString &)));
-        access->setup();
-        return;
-    }
-
-    //new KRun(KUrl(access->filePath()), 0);
-    KRun::runUrl(KUrl(access->filePath()), "inode/directory", 0);
-
-    hideLancelotWindow();
+    setupDevice(udi, true);
 }
 
 bool Devices::hasContextActions(int index) const
@@ -191,14 +248,18 @@ bool Devices::hasContextActions(int index) const
     return true;
 }
 
-void Devices::setContextActions(int index, QMenu * menu)
+void Devices::setContextActions(int index, Lancelot::PopupMenu * menu)
 {
-    if (index > m_items.size() - 1) return;
+    if (index > size() - 1) return;
 
-    QString udi = m_items.at(index).data.toString();
+    QString udi = itemAt(index).data.toString();
     Solid::Device device(udi);
+    const Solid::StorageAccess * access = device.as < Solid::StorageAccess > ();
 
-    if (device.is<Solid::OpticalDisc>()) {
+    if (access->filePath().isEmpty() || !access->isAccessible()) {
+        menu->addAction(KIcon(device.icon()), i18n("Mount"))
+            ->setData(QVariant(1));
+    } else if (device.is < Solid::OpticalDisc > ()) {
         menu->addAction(KIcon("media-eject"), i18n("Eject"))
             ->setData(QVariant(0));
     } else {
@@ -213,9 +274,37 @@ void Devices::contextActivate(int index, QAction * context)
         return;
     }
 
-    QString udi = m_items.at(index).data.toString();
-    Solid::Device device(udi);
+    QString udi = itemAt(index).data.toString();
+    int data = context->data().toInt();
 
+    if (data == 0) {
+        tearDevice(udi);
+    } else if (data == 1) {
+        setupDevice(udi, false);
+    }
+}
+
+void Devices::deviceSetupDone(Solid::ErrorType error, QVariant errorData, const QString & udi)
+{
+    Q_UNUSED(error);
+    Q_UNUSED(errorData);
+
+    Solid::StorageAccess * access = Solid::Device(udi).as<Solid::StorageAccess>();
+    access->disconnect(this, SLOT(deviceSetupDone(Solid::ErrorType, QVariant, const QString &)));
+
+    if (error || !access || !access->isAccessible()) {
+        m_error = errorData.toString();
+        QTimer::singleShot(0, this, SLOT(showError()));
+        return;
+    }
+
+    KRun::runUrl(KUrl(access->filePath()), "inode/directory", 0);
+    hideLancelotWindow();
+}
+
+void Devices::tearDevice(const QString & udi)
+{
+    Solid::Device device(udi);
     if (device.is<Solid::OpticalDisc>()) {
         Solid::OpticalDrive *drive = device.parent().as<Solid::OpticalDrive>();
         drive->eject();
@@ -228,23 +317,43 @@ void Devices::contextActivate(int index, QAction * context)
     }
 }
 
-void Devices::deviceSetupDone(Solid::ErrorType error, QVariant errorData, const QString & udi)
+void Devices::setupDevice(const QString & udi, bool openAfterSetup)
 {
-    Q_UNUSED(error);
-    Q_UNUSED(errorData);
-    //m_devicesMounting.removeAll(udi);
+    Solid::StorageAccess * access = Solid::Device(udi).as < Solid::StorageAccess > ();
 
-    Solid::StorageAccess * access = Solid::Device(udi).as<Solid::StorageAccess>();
-    access->disconnect(this, SLOT(deviceSetupDone(Solid::ErrorType, QVariant, const QString &)));
+    if (!access) return;
 
-    if (!access || !access->isAccessible()) {
-        QMessageBox::critical(NULL, i18n("Failed to open"), i18n("The requested device can not be accessed."));
+    if (access->filePath().isEmpty() || !access->isAccessible()) {
+        if (openAfterSetup) {
+            connect(access, SIGNAL(setupDone(Solid::ErrorType, QVariant, const QString &)),
+                this, SLOT(deviceSetupDone(Solid::ErrorType, QVariant, const QString &)));
+        }
+        access->setup();
         return;
+    } else if (openAfterSetup) {
+        KRun::runUrl(KUrl(access->filePath()), "inode/directory", 0);
+        hideLancelotWindow();
     }
-
-    KRun::runUrl(KUrl(access->filePath()), "inode/directory", 0);
-    hideLancelotWindow();
 }
 
+void Devices::showError()
+{
+    KMessageBox::detailedError(NULL, i18n("The requested device can not be accessed."), m_error, i18n("Failed to open"));
+}
+
+QMimeData * Devices::mimeData(int index) const
+{
+    QString udi = itemAt(index).data.toString();
+
+    Solid::StorageAccess * access = Solid::Device(udi).as < Solid::StorageAccess > ();
+
+    if (!access) return NULL;
+
+    if (access->filePath().isEmpty() || !access->isAccessible()) {
+        return NULL;
+    } else {
+        return BaseModel::mimeForUrl(access->filePath());
+    }
+}
 
 } // namespace Models
