@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2007 Ivan Cukic <ivan.cukic(at)kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License version 2,
@@ -33,13 +33,20 @@ public:
     explicit FolderModel(QString dirPath, QDir::SortFlags sort = QDir::NoSort);
     virtual ~FolderModel();
 
-protected:
-    void load();
+    L_Override bool dataDropAvailable(int where, const QMimeData * mimeData);
+    L_Override void dataDropped(int where, const QMimeData * mimeData);
 
 protected:
+    void load();
+    void save();
+
+protected:
+    void addItem(const KUrl & url);
+
     KDirLister * m_dirLister;
     QString m_dirPath;
     QDir::SortFlags m_sort;
+    QStringList m_items;
 
 protected Q_SLOTS:
     void clear();
