@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2007 Ivan Cukic <ivan.cukic(at)kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser/Library General Public License version 2,
@@ -20,13 +20,13 @@
 #ifndef LANCELOT_BASIC_WIDGET_H
 #define LANCELOT_BASIC_WIDGET_H
 
-#include <lancelot/lancelot_export.h>
-#include <lancelot/lancelot.h>
+#include <QtGui/QGraphicsScene>
+#include <QtGui/QIcon>
 
 #include <plasma/svg.h>
 
-#include <QtGui/QGraphicsScene>
-#include <QtGui/QIcon>
+#include <lancelot/lancelot.h>
+#include <lancelot/lancelot_export.h>
 #include <lancelot/widgets/Widget.h>
 
 namespace Lancelot
@@ -50,18 +50,10 @@ class LANCELOT_EXPORT BasicWidget: public Lancelot::Widget {
     Q_PROPERTY ( QString description READ description WRITE setDescription ) L_EXTRA ( i18n )
     Q_PROPERTY ( Qt::Orientation innerOrientation READ innerOrientation WRITE setInnerOrientation )
 
-    L_WIDGET
-    L_INCLUDE(lancelot/widgets/BasicWidget.h QIcon QSize QString)
+    // @puck L_WIDGET
+    // @puck L_INCLUDE(lancelot/widgets/BasicWidget.h QIcon QSize QString)
 
 public:
-    /**
-     * BasicWidget related properties
-     */
-    enum Property {
-        BlurTextShadow = Widget::UserProperty,
-        TextColorBackground,
-        UserProperty = Widget::UserProperty + 16
-    };
     /**
      * Creates a new Lancelot::BasicWidget
      * @param parent parent item
@@ -185,7 +177,6 @@ public:
     virtual void setShortcutKey(const QString & key);
 
 protected:
-
     /**
      * Common implementation of icon/text/description
      * rendering
