@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2007 Ivan Cukic <ivan.cukic(at)kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser/Library General Public License version 2,
@@ -22,9 +22,8 @@
 
 #include <lancelot/lancelot.h>
 #include <lancelot/lancelot_export.h>
-
-#include <lancelot/widgets/Widget.h>
 #include <lancelot/widgets/BasicWidget.h>
+#include <lancelot/widgets/Widget.h>
 
 #define EXTENDER_SIZE 20
 
@@ -41,13 +40,15 @@ class LANCELOT_EXPORT ExtenderButton : public Lancelot::BasicWidget
 {
     Q_OBJECT
 
-    Q_PROPERTY ( ExtenderPosition extenderPosition READ extenderPosition WRITE setExtenderPosition )
-    Q_PROPERTY ( ActivationMethod activationMethod READ activationMethod WRITE setActivationMethod )
+    /* type: ExtenderPosition */
+    Q_PROPERTY ( int extenderPosition READ extenderPosition WRITE setExtenderPosition )
+    /* type: ActivationMethod */
+    Q_PROPERTY ( int activationMethod READ activationMethod WRITE setActivationMethod )
     Q_PROPERTY ( bool checkable READ isCheckable WRITE setCheckable )
     Q_PROPERTY ( bool checked READ isChecked WRITE setChecked )
 
-    L_WIDGET
-    L_INCLUDE(lancelot/widgets/ExtenderButton.h lancelot/lancelot.h)
+    // @puck L_WIDGET
+    // @puck L_INCLUDE(lancelot/widgets/ExtenderButton.h lancelot/lancelot.h)
 
 public:
     /**
@@ -94,23 +95,23 @@ public:
      * Sets the position of the extender
      * @param position new position
      */
-    void setExtenderPosition(Lancelot::ExtenderPosition position);
+    void setExtenderPosition(int position);
 
     /**
      * @returns the extender position
      */
-    Lancelot::ExtenderPosition extenderPosition() const;
+    int extenderPosition() const;
 
     /**
      * Sets the activation method of the ExtenderButton
      * @param method new activation method
      */
-    void setActivationMethod(Lancelot::ActivationMethod method);
+    void setActivationMethod(int method);
 
     /**
      * @returns activation method
      */
-    Lancelot::ActivationMethod activationMethod() const;
+    int activationMethod() const;
 
     /**
      * Makes the button checkable when set to true
@@ -128,10 +129,8 @@ public:
      */
     bool isChecked() const;
 
-    L_Override void geometryUpdated();
-
-    L_Override void setGroup(WidgetGroup * group = NULL);
-    L_Override void groupUpdated();
+    L_Override void setGroup(Group * group = NULL);
+    // L_Override void groupUpdated();
 
     L_Override QRectF boundingRect() const;
 
@@ -169,6 +168,7 @@ Q_SIGNALS:
 protected:
     L_Override void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
     L_Override void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
+    L_Override void resizeEvent(QGraphicsSceneResizeEvent * event);
     L_Override void hideEvent(QHideEvent * event);
 
 protected Q_SLOTS:
