@@ -40,6 +40,7 @@ Luna::Luna(QObject *parent, const QVariantList &args)
 {
     setHasConfigurationInterface(true);
     setAspectRatioMode(Plasma::ConstrainedSquare);
+    setBackgroundHints(Plasma::Applet::NoBackground);
     resize(QSize(82, 82));
 }
 
@@ -169,6 +170,8 @@ void Luna::calcStatus(time_t time)
     if ( fm.daysTo( now ) == 0 ) {
         counter = 14;
         toolTipData.setMainText( i18n( "Full Moon" ) );
+        Plasma::ToolTipManager::self()->setContent(this, toolTipData);
+        update();
         return;
     } else if ( counter <= 15 && counter >= 13 ) {
         counter = 14 + fm.daysTo( now );
