@@ -17,20 +17,20 @@
 
 #include "weatherstation.h"
 #include <QGraphicsLinearLayout>
-#include <QPainter>
 #include <KConfigDialog>
 #include <KConfigGroup>
-#include <KRun>
 #include <KToolInvocation>
 #include <Plasma/Containment>
 #include <Plasma/Theme>
 #include <Plasma/ToolTipManager>
 #include <plasma/weather/weatherutils.h>
-#include <conversion/converter.h>
+#include <KUnitConversion/Converter>
 #include <plasmaweather/weatherconfig.h>
 #include <math.h>
 #include "lcd.h"
 
+using namespace KUnitConversion;
+
 WeatherStation::WeatherStation(QObject *parent, const QVariantList &args)
     : WeatherPopupApplet(parent, args), m_lcd(0), m_lcdPanel(0)
 {
@@ -68,7 +68,7 @@ void WeatherStation::init()
     KConfigGroup cfg = config();
 
     m_useBackground = cfg.readEntry("background", true);
-    m_showToolTip = cfg.readEntry("tooltip", false);
+    m_showToolTip = cfg.readEntry("tooltip", true);
     setBackground();
 
     setLCDIcon();
@@ -116,6 +116,11 @@ void WeatherStation::configAccepted()
             m_appearanceConfig.backgroundCheckBox->isChecked());
     cfg.writeEntry("tooltip", m_showToolTip =
             m_appearanceConfig.tooltipCheckBox->isChecked());
+
+    if (!m_showToolTip) {
+        m_lcd->setLabel("weather-label", i18n("CURRENT WEATHER"));
+        Plasma::ToolTipManager::self()->clearContent(this);
+    }
     setBackground();
 
     WeatherPopupApplet::configAccepted();
@@ -129,12 +134,12 @@ void WeatherStation::setLCDIcon()
     setPopupIcon(QIcon(m_lcdPanel->toPixmap()));
 }
 
-Conversion::Value WeatherStation::value(const QString& value, const QString& unit)
+Value WeatherStation::value(const QString& value, int unit)
 {
     if (value.isEmpty() || value == "N/A") {
-        return Conversion::Value();
+        return Value();
     }
-    return Conversion::Value(value, unit);
+    return Value(value.toDouble(), unit);
 }
 
 void WeatherStation::dataUpdated(const QString& source, const Plasma::DataEngine::Data &data)
@@ -143,22 +148,21 @@ void WeatherStation::dataUpdated(const QString& source, const Plasma::DataEngine
     WeatherPopupApplet::dataUpdated(source, data);
 
     if (data.contains("Place")) {
-        Conversion::Value temp = value(data["Temperature"].toString(),
-                WeatherUtils::getUnitString(data["Temperature Unit"].toInt(), true));
-        setTemperature(temp);
+        QString v = data["Temperature"].toString();
+        Value temp = value(v, data["Temperature Unit"].toInt());
+        setTemperature(temp, (v.indexOf('.') > -1));
         setPressure(conditionIcon(),
-                    value(data["Pressure"].toString(),
-                        WeatherUtils::getUnitString(data["Pressure Unit"].toInt())),
+                    value(data["Pressure"].toString(), data["Pressure Unit"].toInt()),
                     data["Pressure Tendency"].toString());
         setHumidity(data["Humidity"].toString());
-        setWind(value(data["Wind Speed"].toString(),
-                WeatherUtils::getUnitString(data["Wind Speed Unit"].toInt(), true)),
+        setWind(value(data["Wind Speed"].toString(), data["Wind Speed Unit"].toInt()),
                 data["Wind Direction"].toString());
         m_lcd->setLabel("provider-label", data["Credit"].toString());
         m_url = data["Credit Url"].toString();
         m_lcd->setItemClickable("provider-click", !m_url.isEmpty());
 
         if (m_showToolTip) {
+            m_lcd->setLabel("weather-label", data["Place"].toString().toUpper());
             Plasma::ToolTipContent ttc(data["Place"].toString(),
                     i18n("Last updated: %1", KGlobal::locale()->formatDateTime(QDateTime::currentDateTime(), KLocale::FancyLongDate)));
             Plasma::ToolTipManager::self()->setContent(this, ttc);
@@ -166,16 +170,17 @@ void WeatherStation::dataUpdated(const QString& source, const Plasma::DataEngine
     }
 }
 
-QString WeatherStation::fitValue(const Conversion::Value& value, int digits)
+QString WeatherStation::fitValue(const Value& value, int digits)
 {
     if (!value.isValid()) {
         return "-";
     }
     double v = value.number();
-    int mainDigits = (int)floor(log(fabs(v))) + 1;
+    int mainDigits = (int)floor(log10(fabs(v))) + 1;
     int precision = 0;
 
-    if (mainDigits < 3 && mainDigits + (v < 0)?1:0 + 1 < digits) {
+    mainDigits += ((v < 0) ? 1 : 0); // minus sign
+    if (mainDigits < digits) {
         precision = 1;
     }
     return QString::number(v, 'f', precision);
@@ -223,18 +228,18 @@ QStringList WeatherStation::fromCondition(const QString& condition)
     } else if (condition == "weather-storm") {
         result << "cloud" << "flash" << "water_drops";
     }
-    //kDebug() << result;
+    //kDebug() << condition << result;
     return result;
 }
 
-void WeatherStation::setPressure(const QString& condition, const Conversion::Value& pressure,
+void WeatherStation::setPressure(const QString& condition, const Value& pressure,
                                  const QString& tendencyString)
 {
     QStringList current;
     current = fromCondition(condition);
     m_lcd->setGroup("weather", current);
 
-    Conversion::Value value = Conversion::Converter::self()->convert(pressure, pressureUnit());
+    Value value = pressure.convertTo(pressureUnit());
     QString s = fitValue(value, 5);
     m_lcd->setNumber("pressure", s);
     m_lcd->setLabel("pressure-unit-label", value.unit()->symbol());
@@ -257,13 +262,16 @@ void WeatherStation::setPressure(const QString& condition, const Conversion::Val
     }
 }
 
-void WeatherStation::setTemperature(const Conversion::Value& temperature)
+void WeatherStation::setTemperature(const Value& temperature, bool hasDigit)
 {
-    Conversion::Value v = Conversion::Converter::self()->convert(temperature, temperatureUnit());
+    hasDigit = hasDigit || (temperatureUnit() != temperature.unit());
+    Value v = temperature.convertTo(temperatureUnit());
     m_lcd->setLabel("temperature-unit-label", v.unit()->symbol());
     m_lcdPanel->setLabel("temperature-unit-label", v.unit()->symbol());
-    m_lcd->setNumber("temperature", fitValue(v , 4));
-    m_lcdPanel->setNumber("temperature", fitValue(v , 3));
+    QString tmp = hasDigit ? fitValue(v , 4) : QString::number(v.number());
+    m_lcd->setNumber("temperature", tmp);
+    tmp = hasDigit ? fitValue(v , 3) : QString::number(v.number());
+    m_lcdPanel->setNumber("temperature", tmp);
     setLCDIcon();
 }
 
@@ -277,10 +285,10 @@ void WeatherStation::setHumidity(QString humidity)
     m_lcd->setNumber("humidity", humidity);
 }
 
-void WeatherStation::setWind(const Conversion::Value& speed, const QString& dir)
+void WeatherStation::setWind(const Value& speed, const QString& dir)
 {
     //kDebug() << speed.number() << speed.unit()->symbol() << dir;
-    Conversion::Value value = Conversion::Converter::self()->convert(speed, speedUnit());
+    Value value = speed.convertTo(speedUnit());
     QString s = fitValue(value, 3);
 
     if (dir == "N/A") {
